"""A submodule with for implementations of area managers."""

from .batch import BatchAreaManager
from .custom_grid import CustomGridAreaManager
from .utm import UtmZoneAreaManager
